pub enum BandlimitedWaveform {
Sine,
Saw,
Pulse {
duty: f32,
},
Triangle,
}Expand description
Periodic waveform generated by BandlimitedOscillator.
Variants
Sine
A sinusoid, which is already bandlimited.
Saw
A rising sawtooth with its discontinuity corrected by the selected policy.
Pulse
A pulse wave with a duty cycle in the open interval (0, 1).
Triangle
A triangle obtained by integrating a corrected square wave.