pub struct CombFilter { /* private fields */ }Expand description
A feedback comb filter Processor built on a delay line.
Implementations
Sourceimpl CombFilter
impl CombFilter
Sourcepub fn milliseconds(delay_ms: f32, feedback: f32) -> Self
pub fn milliseconds(delay_ms: f32, feedback: f32) -> Self
Creates a comb filter with the given delay (ms) and feedback amount.