pub struct Compressor { /* private fields */ }Expand description
A per-channel feed-forward compressor Processor.
Implementations
Sourceimpl Compressor
impl Compressor
Sourcepub fn new(threshold_db: f32, ratio: f32) -> Self
pub fn new(threshold_db: f32, ratio: f32) -> Self
Creates a compressor with the given threshold (dB) and ratio (clamped to
>= 1.0), with default timing and unity makeup gain.
Sourcepub fn with_timing(self, attack_ms: f32, release_ms: f32) -> Self
pub fn with_timing(self, attack_ms: f32, release_ms: f32) -> Self
Returns the compressor with attack and release times (ms) set.
Sourcepub fn with_makeup_gain_db(self, makeup_db: f32) -> Self
pub fn with_makeup_gain_db(self, makeup_db: f32) -> Self
Returns the compressor with makeup gain set, in decibels.