pub struct DelayProcessor { /* private fields */ }Expand description
A per-channel delay Processor with feedback and dry/wet mix.
Implementations
Sourceimpl DelayProcessor
impl DelayProcessor
Sourcepub fn new(delay_seconds: f32, max_delay_seconds: f32) -> Self
pub fn new(delay_seconds: f32, max_delay_seconds: f32) -> Self
Creates a delay processor with the given delay and maximum delay, in seconds, defaulting to a fully wet, feedback-free mix.
Sourcepub fn milliseconds(delay_ms: f32, max_delay_ms: f32) -> Self
pub fn milliseconds(delay_ms: f32, max_delay_ms: f32) -> Self
Creates a delay processor from delay and maximum delay in milliseconds.
Sourcepub fn with_mix(self, dry: f32, wet: f32) -> Self
pub fn with_mix(self, dry: f32, wet: f32) -> Self
Returns the processor with explicit dry and wet mix levels.
Sourcepub fn with_feedback(self, feedback: f32) -> Self
pub fn with_feedback(self, feedback: f32) -> Self
Returns the processor with feedback set, clamped to -0.99..=0.99.