Gain

Struct Gain 

pub struct Gain { /* private fields */ }
A Processor that scales every channel by a fixed linear gain.

Examples

use sim_lib_audio_dsp::Gain;

let gain = Gain::new(0.5);
assert_eq!(gain.gain(), 0.5);

Implementations

Source

impl Gain

pub fn new(gain: f32) -> Self

Creates a gain processor with the given linear gain.

pub fn gain(&self) -> f32

Returns the linear gain.