pub struct OversamplingWrapper<P: NonlinearSampleProcessor> { /* private fields */ }Expand description
A Processor that runs a NonlinearSampleProcessor at an integer
oversampling factor, interpolating each input across the oversampled steps.
Implementations
Sourceimpl<P: NonlinearSampleProcessor> OversamplingWrapper<P>
impl<P: NonlinearSampleProcessor> OversamplingWrapper<P>
Sourceimpl OversamplingWrapper<TanhClipper>
impl OversamplingWrapper<TanhClipper>
Sourcepub fn soft_clipper(drive: f32, factor: u8) -> Self
pub fn soft_clipper(drive: f32, factor: u8) -> Self
Creates an oversampled tanh soft clipper with the given drive and factor.