pub struct Waveshaper { /* private fields */ }Expand description
A Processor applying a nonlinear waveshaping curve with drive and output
gain.
Implementations
Sourceimpl Waveshaper
impl Waveshaper
Sourcepub fn new(shape: Waveshape, drive: f32) -> Self
pub fn new(shape: Waveshape, drive: f32) -> Self
Creates a waveshaper with the given curve and drive (clamped to >= 0).
Sourcepub fn with_output_gain(self, output_gain: f32) -> Self
pub fn with_output_gain(self, output_gain: f32) -> Self
Returns the waveshaper with its post-curve output gain set.
Sourcepub fn process_sample(&self, input: f32) -> f32
pub fn process_sample(&self, input: f32) -> f32
Applies the drive, curve, and output gain to one sample.